pub struct NativeSingleThreadDriver { /* private fields */ }Expand description
Native cooperative runtime driver backed by the canonical VM kernel.
Implementations
Sourceimpl NativeSingleThreadDriver
impl NativeSingleThreadDriver
Sourcepub fn load_choreography_owned(
&mut self,
image: &CodeImage,
owner_id: impl Into<String>,
) -> Result<OwnedSession, VMError>
pub fn load_choreography_owned( &mut self, image: &CodeImage, owner_id: impl Into<String>, ) -> Result<OwnedSession, VMError>
Preferred choreography open path that returns an ownership-bearing handle.
Errors
Returns a VMError if the choreography cannot be loaded or claimed.
Sourcepub fn step_round(
&mut self,
handler: &dyn EffectHandler,
n: usize,
) -> Result<StepResult, VMError>
pub fn step_round( &mut self, handler: &dyn EffectHandler, n: usize, ) -> Result<StepResult, VMError>